@@ -1,14 +1,18 @@
 package Nodejs::Util;
 
-our $DATE = '2016-07-01'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-07-03'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(get_nodejs_path nodejs_available);
+our @EXPORT_OK = qw(
+                       get_nodejs_path
+                       nodejs_available
+                       system_nodejs
+               );
 
 our %SPEC;
 
@@ -18,7 +22,7 @@ my %arg_all = (
         summary => 'Find all node.js instead of the first found',
         description => <<'_',
 
-If this option is set to true, will return an array of paths intead of paths.
+If this option is set to true, will return an array of paths intead of path.
 
 _
     },
@@ -85,7 +89,10 @@ _
         min_version => {
             schema => 'str*',
         },
-        # XXX extra_paths (but we can localize $ENV{PATH} to accomplish this)
+        path => {
+            summary => 'Search this instead of PATH environment variable',
+            schema => ['str*'],
+        },
         %arg_all,
     },
 };
@@ -95,7 +102,10 @@ sub nodejs_available {
     my %args = @_;
     my $all = $args{all};
 
-    my $paths = get_nodejs_path(all => 1);
+    my $paths = do {
+        local $ENV{PATH} = $args{path} if defined $args{path};
+        get_nodejs_path(all => 1);
+    };
     defined $paths or return [412, "node.js not detected in PATH"];
 
     my $res = [200, "OK"];
@@ -121,7 +131,7 @@ sub nodejs_available {
             };
         }
         push @filtered_paths, $path;
-        push @versions, "$v";
+        push @versions, defined($v) ? "$v" : undef;
     }
 
     $res->[2]                 = $all ? \@filtered_paths : $filtered_paths[0];
@@ -138,6 +148,42 @@ sub nodejs_available {
     $res;
 }
 
+sub system_nodejs {
+    require IPC::System::Options;
+    my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+
+    my $harmony_scoping = delete $opts->{harmony_scoping};
+    my $path = delete $opts->{path};
+
+    my %detect_nodejs_args;
+    if ($harmony_scoping) {
+        $detect_nodejs_args{min_version} = '0.5.10';
+    }
+    if ($path) {
+        $detect_nodejs_args{path} = $path;
+    }
+    my $detect_res = nodejs_available(%detect_nodejs_args);
+    die "No eligible node.js binary available: ".
+        "$detect_res->[0] - $detect_res->[1]" unless $detect_res->[0] == 200;
+
+    my @extra_args;
+    if ($harmony_scoping) {
+        my $node_v = $detect_res->[3]{'func.version'};
+        if (version->parse($node_v) < version->parse("2.0.0")) {
+            push @extra_args, "--use_strict", "--harmony_scoping";
+        } else {
+            push @extra_args, "--use_strict";
+        }
+    }
+
+    IPC::System::Options::system(
+        $opts,
+        $detect_res->[2],
+        @extra_args,
+        @_,
+    );
+}
+
 1;
 # ABSTRACT: Utilities related to Node.js
 
@@ -153,7 +199,7 @@ Nodejs::Util - Utilities related to Node.js
 
 =head1 VERSION
 
-This document describes version 0.005 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2016-07-01.
+This document describes version 0.006 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2016-07-03.
 
 =head1 FUNCTIONS
 
@@ -175,7 +221,7 @@ Arguments ('*' denotes required arguments):
 
 Find all node.js instead of the first found.
 
-If this option is set to true, will return an array of paths intead of paths.
+If this option is set to true, will return an array of paths intead of path.
 
 =back
 
@@ -208,10 +254,14 @@ Arguments ('*' denotes required arguments):
 
 Find all node.js instead of the first found.
 
-If this option is set to true, will return an array of paths intead of paths.
+If this option is set to true, will return an array of paths intead of path.
 
 =item * B<min_version> => I<str>
 
+=item * B<path> => I<str>
+
+Search this instead of PATH environment variable.
+
 =back
 
 Returns an enveloped result (an array).
@@ -225,6 +275,28 @@ that contains extra information.
 
 Return value:  (any)
 
+=head2 system_nodejs([ \%opts ], @argv)
+
+Will call L<IPC::System::Options>'s system(), but with node.js binary as the
+first argument. Known options:
+
+=over
+
+=item * harmony_scoping => bool
+
+If set to 1, will attempt to enable block scoping. This means at least node.js
+v0.5.10 (where C<--harmony_scoping> is first recognized). But
+C<--harmony_scoping> is no longer needed after v2.0.0 and no longer recognized
+in later versions.
+
+=item * path => str
+
+Will be passed to C<nodejs_available()>.
+
+=back
+
+Other options will be passed to C<IPC::System::Options>'s C<system()>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Nodejs-Util>.
